@@ -31,15 +31,13 @@ caller to provide CIM-XML formatted input data and interpret the result data
 as CIM-XML.
 '''
 
-from __future__ import print_function, absolute_import
 
 import re
 import os
 import base64
 import ssl
 import warnings
-import six
-from six.moves import urllib
+import urllib
 import requests
 from requests.packages import urllib3
 
@@ -183,22 +181,22 @@ def parse_url(url, allow_defaults=True):
         _host = m.group(1)
         _zone_index = m.group(2)
         if _zone_index is not None:
-            host = '[{0}-{1}]'.format(_host, _zone_index)
+            host = f'[{_host}-{_zone_index}]'
         else:
-            host = '[{0}]'.format(_host)
+            host = f'[{_host}]'
     else:
         m = URL_IPV6_TEXT_PATTERN.match(host)
         if m:
             # It is an IPv6 address in RFC4007 text syntax
-            _host = '{0}:{1}'.format(m.group(1), m.group(2))
+            _host = f'{m.group(1)}:{m.group(2)}'
             _zone_index = m.group(3)
             if _zone_index is not None:
-                host = '[{0}-{1}]'.format(_host, _zone_index)
+                host = f'[{_host}-{_zone_index}]'
             else:
-                host = '[{0}]'.format(_host)
+                host = f'[{_host}]'
 
-    hostport = u'{0}:{1}'.format(host, port)
-    url = u'{0}://{1}'.format(scheme, hostport)
+    hostport = f'{host}:{port}'
+    url = f'{scheme}://{hostport}'
 
     return scheme, hostport, url
 
@@ -217,10 +215,10 @@ def pywbem_requests_exception(exc, conn):
     if isinstance(message, urllib3.exceptions.HTTPError):
         return pywbem_urllib3_exception(message, conn)
 
-    if not isinstance(message, six.string_types):
+    if not isinstance(message, str):
         warnings.warn(
-            "requests exception {} has a {} object as args[0] - "
-            "converting to string".format(type(exc), type(message)),
+            f"requests exception {type(exc)} has a {type(message)} object "
+            "as args[0] - converting to string",
             RequestExceptionWarning, 1)
         message = str(message)
 
@@ -307,10 +305,10 @@ def pywbem_urllib3_exception(exc, conn):
     assert isinstance(exc, urllib3.exceptions.HTTPError)
 
     message = exc.args[0]
-    if not isinstance(message, six.string_types):
+    if not isinstance(message, str):
         warnings.warn(
-            "urllib3 exception {} has a {} object as args[0] - "
-            "converting to string".format(type(exc), type(message)),
+            f"urllib3 exception {type(exc)} has a {type(message)} object "
+            "as args[0] - converting to string",
             RequestExceptionWarning, 1)
         message = str(message)
 
@@ -321,9 +319,6 @@ def pywbem_urllib3_exception(exc, conn):
         if m:
             exc_name = m.group(1)
             exc_message = m.group(2)
-            if exc_message.endswith(','):
-                # Python <3.6 represents it as tuple with trailing comma
-                exc_message = exc_message.rstrip(',')
             if exc_message.startswith('"'):
                 exc_message = exc_message.strip('"')
             elif exc_message.startswith("'"):
@@ -347,8 +342,8 @@ def pywbem_urllib3_exception(exc, conn):
         else:
             warnings.warn(
                 "urllib3 exception MaxRetryError does not match the "
-                "'Caused by' pattern: {!r} - re-raising it directly".
-                format(message), RequestExceptionWarning, 1)
+                f"'Caused by' pattern: {message!r} - re-raising it directly",
+                RequestExceptionWarning, 1)
             exc_name = exc.__class__.__name__
             exc_message = message
 
@@ -358,8 +353,8 @@ def pywbem_urllib3_exception(exc, conn):
                 read_timeout = float(m.group(1))
                 if read_timeout == HTTP_CONNECT_TIMEOUT:
                     exc_message = (
-                        "Could not send request to {} within {:.0f} sec".
-                        format(conn.url, read_timeout))
+                        f"Could not send request to {conn.url} within "
+                        f"{read_timeout:.0f} sec")
                     new_exc = ConnectionError(exc_message, conn_id=conn.conn_id)
                     new_exc.__cause__ = None
                     return new_exc
@@ -370,8 +365,8 @@ def pywbem_urllib3_exception(exc, conn):
             m = re.search(r'^Read timed out', exc_message)
             if m:
                 exc_message = (
-                    "No response received from {} within {} sec".
-                    format(conn.url, conn.timeout))
+                    f"No response received from {conn.url} within "
+                    f"{conn.timeout} sec")
 
             new_exc = TimeoutError(exc_message, conn_id=conn.conn_id)
             new_exc.__cause__ = None
@@ -404,20 +399,20 @@ def exc_message_amended(message, conn):
     """
     if conn.scheme == 'https':
         message = message + \
-            "; OpenSSL version used: {}".format(ssl.OPENSSL_VERSION)
+            f"; OpenSSL version used: {ssl.OPENSSL_VERSION}"
     return message
 
 
 def debug_exc(exc):
     """Debug: Return a debug message for the exception"""
     arg_strings = [
-        "exception: {}".format(type(exc)),
-        # "dir(exc)={}".format(dir(exc)),
-        # "dir(exc.request)={}".format(dir(exc.request)),
-        # "dir(exc.response)={}".format(dir(exc.response)),
+        f"exception: {type(exc)}",
+        # f"dir(exc)={dir(exc)}",
+        # f"dir(exc.request)={dir(exc.request)}",
+        # f"dir(exc.response)={dir(exc.response)}",
     ]
     for i, arg in enumerate(exc.args):
-        arg_strings.append("arg[{}] ({}) = {}".format(i, type(arg), arg))
+        arg_strings.append(f"arg[{i}] ({type(arg)}) = {arg}")
     message = "; ".join(arg_strings)
     return message
 
@@ -473,7 +468,7 @@ def wbem_request(conn, req_data, cimxml_headers, target_type='server'):
         target = '/cimom'
     else:
         target = ''
-    target_url = '{}{}'.format(conn.url, target)
+    target_url = f'{conn.url}{target}'
 
     # Make sure the data parameter is converted to a UTF-8 encoded byte string.
     # This is important because according to RFC2616, the Content-Length HTTP
@@ -484,15 +479,15 @@ def wbem_request(conn, req_data, cimxml_headers, target_type='server'):
 
     req_headers = {
         'Content-type': 'application/xml; charset="utf-8"',
-        'Content-length': '{}'.format(len(req_body)),
+        'Content-length': f'{len(req_body)}',
     }
     req_headers.update(dict(cimxml_headers))
 
     if target_type == 'server' and conn.creds is not None:
-        auth = '{0}:{1}'.format(conn.creds[0], conn.creds[1])
+        auth = f'{conn.creds[0]}:{conn.creds[1]}'
         auth64 = _ensure_unicode(base64.b64encode(
             _ensure_bytes(auth))).replace('\n', '')
-        req_headers['Authorization'] = 'Basic {0}'.format(auth64)
+        req_headers['Authorization'] = f'Basic {auth64}'
 
     if conn.operation_recorders:
         for recorder in conn.operation_recorders:
@@ -508,25 +503,25 @@ def wbem_request(conn, req_data, cimxml_headers, target_type='server'):
     try:
         try:
             if DEBUG_EXCEPTIONS:
-                print("Debug: pywbem wbem_request: Calling session.post() with "
-                      "timeout=(connect={}, read={}) for {} on {} with {}".
-                      format(HTTP_CONNECT_TIMEOUT, conn.timeout,
-                             cimxml_headers[1][1], cimxml_headers[2][1],
-                             conn.session.adapters['https://'].max_retries))
+                print("Debug: pywbem wbem_request: Calling session.post() "
+                      f"with timeout=(connect={HTTP_CONNECT_TIMEOUT}, "
+                      f"read={conn.timeout}) for {cimxml_headers[1][1]} on "
+                      f"{cimxml_headers[2][1]} with "
+                      f"{conn.session.adapters['https://'].max_retries}")
             resp = conn.session.post(
                 target_url, data=req_body, headers=req_headers,
                 timeout=(HTTP_CONNECT_TIMEOUT, conn.timeout))
         except Exception as _exc:
             if DEBUG_EXCEPTIONS:
-                print("Debug: pywbem wbem_request: session.post() raised: {}".
-                      format(debug_exc(_exc)))
+                print("Debug: pywbem wbem_request: session.post() raised: "
+                      f"{debug_exc(_exc)}")
             raise
     except requests.exceptions.RequestException as exc:
         raise pywbem_requests_exception(exc, conn)
     except urllib3.exceptions.HTTPError as exc:
         warnings.warn(
-            "requests raised an urllib3 exception {} directly".
-            format(type(exc)), RequestExceptionWarning, 1)
+            f"requests raised an urllib3 exception {type(exc)} directly",
+            RequestExceptionWarning, 1)
         raise pywbem_urllib3_exception(exc, conn)
 
     if target_type == 'server':
@@ -554,8 +549,8 @@ def wbem_request(conn, req_data, cimxml_headers, target_type='server'):
 
         if target_type == 'server' and resp.status_code == 401:
 
-            msg = "WBEM server returned HTTP status {0} ({1}).". \
-                format(resp.status_code, resp.reason)
+            msg = (f"WBEM server returned HTTP status {resp.status_code} "
+                   f"({resp.reason}).")
 
             # According to RFC2016/2017, the server must include a
             # WWW-Authenticate header in the response when returning 401.
@@ -609,8 +604,8 @@ def wbem_request(conn, req_data, cimxml_headers, target_type='server'):
             not resp_content_type.startswith('application/xml') and \
             not resp_content_type.startswith('text/xml'):
         raise HeaderParseError(
-            "WBEM server returned invalid Content-type header: {!r}".
-            format(resp_content_type),
+            "WBEM server returned invalid Content-type header: "
+            f"{resp_content_type!r}",
             conn_id=conn.conn_id, request_data=req_body,
             response_data=resp.text)
 
@@ -657,7 +652,7 @@ def get_cimobject_header(obj):
     """
 
     # Local namespace path
-    if isinstance(obj, six.string_types):
+    if isinstance(obj, str):
         return obj
 
     # Local class path
