@@ -72,46 +72,27 @@ objects, :term:`string`, in addition to
 
 # This module is meant to be safe for 'import *'.
 
-from __future__ import absolute_import
-
 import copy
 import re
+from datetime import tzinfo, datetime, timedelta, timezone
 
-from datetime import tzinfo, datetime, timedelta
-import six
 from .config import ENFORCE_INTEGER_RANGE
 from ._utils import _ensure_unicode, _hash_item, _format, _to_unicode, \
     _eq_item
 
-if six.PY3:
-    from datetime import timezone
-
-if six.PY2:
-    # pylint: disable=invalid-name,undefined-variable
-    _Longint = long  # noqa: F821
-else:
-    # pylint: disable=invalid-name
-    _Longint = int
-
-
 __all__ = ['cimtype', 'type_from_name', 'MinutesFromUTC', 'CIMType',
            'CIMDateTime', 'CIMInt', 'Uint8', 'Sint8', 'Uint16', 'Sint16',
            'Uint32', 'Sint32', 'Uint64', 'Sint64', 'CIMFloat', 'Real32',
            'Real64', 'Char16', '_CIMComparisonMixin']
 
 
-class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
+class _CIMComparisonMixin:  # pylint: disable=too-few-public-methods
     """
     Mixin class providing default implementations for equality test
     operators and hash function.
 
     The implementations of ordering tests are also provided and raise an
     exception because ordering of CIM objects is not supported.
-
-    In Python 2, the rich comparison operators (e.g. `__eq__()`) have
-    precedence over the traditional comparator method (`__cmp__()`).
-    In Python 3, the comparator method (`__cmp__()`) no longer exists.
-    Therefore, implementing the rich comparison operators works in both.
     """
 
     __slots__ = []
@@ -141,8 +122,8 @@ class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
         is not supported.
         """
         raise TypeError(
-            "'{}' not supported between instances of '{}' and '{}'".
-            format(op, type(self), type(other)))
+            f"'{op}' not supported between instances of '{type(self)}' and "
+            f"'{type(other)}'")
 
     def __lt__(self, other):
         ""  # Avoids docstring to be inherited
@@ -175,23 +156,20 @@ class _CIMComparisonMixin(object):  # pylint: disable=too-few-public-methods
         raise NotImplementedError
 
 
-class SlottedPickleMixin(object):
+class SlottedPickleMixin:
     """
-    On Python 2, the built-in 'pickle' module uses pickle protocol 0 by default.
-    Using protocol 0 causes pickle to raise TypeError for objects with slots
-    that do not define methods __getstate__() and __setstate__().
+    Starting with Python 3.8, the default pickle protocol is protocol 4, which
+    supports objects with slots by default, without requiring that they define
+    methods __getstate__() and __setstate__().
 
-    In Python 3.0, the default pickle protocol changed to protocol 3 and in
-    Python 3.8 to protocol 4, both of which support objects with slots by
-    default, without requiring that they define methods __getstate__() and
-    __setstate__().
+    However, objects pickled from Python versions < 3.8 (using the built-in
+    methods) saved all attributes in one shot by saving their __dict__ value,
+    so the default unpickling after introduction of slots attempts to set the
+    __dict__ which fails with AttributeError.
 
-    That led to the idea to provide these methods only when running on
-    Python 2. However, it turns out that objects pickled before this change
-    (using the built-in methods) save all attributes in one shot by saving
-    their __dict__ value, so the default unpickling after introduction of
-    slots attempts to set the __dict__ which fails with AttributeError.
-    Therefore, these methods need to be provided also for Python 3.
+    Therefore, these methods are provided to cover upgrading from use of
+    objects pickled with python versions older than 3.8 to define __getstate__
+    and __setstate__.
 
     Also, because code in pywbem_mock/_resolvermixin.py dynamically added
     the non-existing attributes 'classorigin' and 'propagated' to CIMClass
@@ -350,7 +328,7 @@ class MinutesFromUTC(SlottedPickleMixin, tzinfo):
         # input. Therefore we handle the sign separately.
         sign = '-' if self._offset < 0 else ''
         hh, mm = divmod(abs(self._offset), 60)
-        return "{sign}{hh:02d}:{mm:02d}".format(sign=sign, hh=hh, mm=mm)
+        return f"{sign}{hh:02d}:{mm:02d}"
 
 
 class CIMType(SlottedPickleMixin):  # pylint: disable=too-few-public-methods
@@ -363,8 +341,7 @@ class CIMType(SlottedPickleMixin):  # pylint: disable=too-few-public-methods
     cimtype = None
 
 
-class Char16(CIMType, six.text_type):
-    # pylint: disable=too-few-public-methods
+class Char16(CIMType, str):
     """
     A value of CIM data type char16.
 
@@ -386,7 +363,7 @@ class Char16(CIMType, six.text_type):
     # Changing the string content requires using __new__() instead of __init__()
     def __new__(cls, content=''):
         ""  # Avoids docstring to be inherited
-        return super(Char16, cls).__new__(cls, _ensure_unicode(content))
+        return super().__new__(cls, _ensure_unicode(content))
 
 
 class CIMDateTime(_CIMComparisonMixin, CIMType):
@@ -442,7 +419,7 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
         self.__datetime = None  # datetime value, if timestamp
         self.__precision = None  # 0-based index of first asterisk, or None
         dtarg = _ensure_unicode(dtarg)
-        if isinstance(dtarg, six.text_type):
+        if isinstance(dtarg, str):
             m = self._timestamp_pattern.search(dtarg)
             if m is not None:
                 # timestamp format
@@ -580,7 +557,7 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
         """
         Convert value (int) to a field string, considering precision.
         """
-        value_str = '{0:0{1}d}'.format(value, field_len)
+        value_str = f'{value:0{field_len}d}'
         if self.precision is not None and \
                 self.precision < field_begin + field_len:
             # field is partly or completely affected by precision
@@ -659,13 +636,7 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
         A positive value indicates minutes east of UTC, and a negative
         value indicates minutes west of UTC.
         """
-        if six.PY2:
-            # Effective Python 3.12, utcnow() deprecated, it returns
-            # naive datetime object and warning msg. timezone does
-            # not exist for python 2.7; use utcnow(timezone.utc).
-            utc_unaware = datetime.utcnow()
-        else:
-            utc_unaware = datetime.now(timezone.utc).replace(tzinfo=None)  # noqa: E501 pylint: disable=E0606
+        utc_unaware = datetime.now(timezone.utc).replace(tzinfo=None)
 
         local_unaware = datetime.now()
         if local_unaware < utc_unaware:
@@ -752,9 +723,8 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
             seconds_str = self._to_str(seconds, 12, 2)
             microsecs_str = self._to_str(microsecs, 15, 6)
 
-            ret_str = '{0}{1}{2}{3}.{4}:000'.format(
-                days_str, hours_str, minutes_str, seconds_str,
-                microsecs_str)
+            ret_str = (f'{days_str}{hours_str}{minutes_str}{seconds_str}.'
+                       f'{microsecs_str}:000')
             return ret_str
 
         else:  # timestamp
@@ -780,9 +750,8 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
             second_str = self._to_str(second, 12, 2)
             microsec_str = self._to_str(microsec, 15, 6)
 
-            ret_str = '{0}{1}{2}{3}{4}{5}.{6}{7}{8:03d}'.format(
-                year_str, month_str, day_str, hour_str, minute_str,
-                second_str, microsec_str, sign, offset)
+            ret_str = (f'{year_str}{month_str}{day_str}{hour_str}{minute_str}'
+                       f'{second_str}.{microsec_str}{sign}{offset:03d}')
             return ret_str
 
     def __repr__(self):
@@ -845,10 +814,13 @@ class CIMDateTime(_CIMComparisonMixin, CIMType):
 # CIM integer types
 
 
-class CIMInt(CIMType, _Longint):
+class CIMInt(CIMType, int):
     """
     Base type for CIM integer data types. Derived from :class:`~pywbem.CIMType`
-    and :class:`py3:int` (for Python 3) or :class:`py2:long` (for Python 2).
+    and :class:`py3:int`. The input parameters are consistent with
+    :class:`py3:int` except that argument `x` can also be passed as a keyword
+    input parameter to maintain a consistent interface despite changes to the
+    Python :class:`py3:int` ('x' was changed to positional only in python 3.8).
 
     This class has a concept of a valid range for the represented integer,
     based upon the capability of the CIM data type as defined in
@@ -856,18 +828,27 @@ class CIMInt(CIMType, _Longint):
     or MaxValue qualifiers are not taken into account at this level.
 
     The valid value range is enforced when an instance of a subclass of this
-    class (e.g. :class:`~pywbem.Uint8`) is created. Values outside of the
-    valid range raise a :exc:`ValueError`.
-    The enforcement of the valid value range can be disabled via the
-    configuration variable :data:`~pywbem.config.ENFORCE_INTEGER_RANGE`.
+    class (e.g. :class:`~pywbem.Uint8`) is created. Values outside of the valid
+    range raise a :exc:`ValueError`. Enforcement of the valid value range can
+    be disabled via the configuration variable
+    :data:`~pywbem.config.ENFORCE_INTEGER_RANGE`.
 
     Two objects of subclasses of this base class compare equal if their numeric
     values compare equal. Objects of this class are immutable and
     :term:`hashable`, with the hash value being based on its numeric value.
 
+    Parameters:
+          x (:term:`integer` or :term:`string`):
+            A number or a string that can be converted into an integer number.
+            The parameter 'x' can be either a positional or keyword argument
+            for compatibility with Python<=3.7. Default value: 0.
+
+          base (:term:`integer`):
+            A number representing the number base  (radix) of 'x'. Default
+            value: 10. Allowed only if 'x' is a string.
+
     Instances of subclasses of this class can be initialized with the usual
     input arguments supported by :term:`integer`, for example:
-
     ::
 
         >>> pywbem.Uint8(42)
@@ -879,6 +860,12 @@ class CIMInt(CIMType, _Longint):
         >>> pywbem.Uint8('2A', 16)
         Uint8(cimtype='uint8', 42)
 
+        >>> pywbem.Uint8('2A', base=16)
+        Uint8(cimtype='uint8', 42)
+
+        >>> pywbem.Uint8(x='2A', base=16)
+        Uint8(cimtype='uint8', 42)
+
         >>> pywbem.Uint8('100', 16)
         Traceback (most recent call last):
           . . .
@@ -903,27 +890,32 @@ class CIMInt(CIMType, _Longint):
     maxvalue = None
 
     def __new__(cls, *args, **kwargs):
-        ""  # Avoids docstring to be inherited
+        ""  # Avoids docstring being inherited
 
         # Python 3.7 removed support for passing the value for int() as a
-        # keyword argument named 'x'. It now needs to be passed as a positional
-        # argument. The testclient test case definitions rely on a keyword
-        # argument, so we now transform the keyword arg into a positional
-        # arg.
+        # keyword argument named 'x'. It now must be passed as a positional
+        # argument.  CIMInt has retained the positional or keyword capability
+        # so we transform the keyword arg into a positional arg.
         if 'x' in kwargs:
             args = list(*args)  # args is passed as a tuple
             args.append(kwargs.pop('x'))
 
-        value = _Longint(*args, **kwargs)
+        value = int(*args, **kwargs)
         if ENFORCE_INTEGER_RANGE:
             if value > cls.maxvalue or value < cls.minvalue:
                 raise ValueError(
                     _format("Integer value {0} is out of range for CIM "
                             "datatype {1}", value, cls.cimtype))
-        # The value needs to be processed here, because int/long is immutable
-        return super(CIMInt, cls).__new__(cls, *args, **kwargs)
+        # The value needs to be processed here, because int is immutable
+        return super().__new__(cls, *args, **kwargs)
 
-    # Note: __str__() is added later, for Python 3.
+    def __str__(self):
+        """
+        Python 3.8 removed __str__() on int causing recursive loop failures.
+        The int.__repr__method returns exactly what is needed for a string
+        representation.
+        """
+        return f"{int.__repr__(self)}"
 
     def __repr__(self):
         """
@@ -932,8 +924,8 @@ class CIMInt(CIMType, _Longint):
         return _format(
             "{s.__class__.__name__}("
             "cimtype={s.cimtype!A}, "
-            "minvalue={s.minvalue}, "  # Avoid long indicator 'L' in Python 2
-            "maxvalue={s.maxvalue}, "  # Avoid long indicator 'L' in Python 2
+            "minvalue={s.minvalue}, "
+            "maxvalue={s.maxvalue}, "
             "{s})",
             s=self)
 
@@ -943,6 +935,13 @@ class Uint8(CIMInt):
     A value of CIM data type uint8. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+          x (:term:`integer` or :term:`string`):
+            A number or a string that can be converted into an integer number.
+
+          base (:term:`integer`):
+            A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -960,6 +959,13 @@ class Sint8(CIMInt):
     A value of CIM data type sint8. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+          x (:term:`integer` or :term:`string`):
+            A number or a string that can be converted into an integer number.
+
+          base (:term:`integer`):
+            A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -977,6 +983,14 @@ class Uint16(CIMInt):
     A value of CIM data type uint16. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          'x' may be a position or keyword argument.
+
+        base (:term:`integer`):
+          A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -994,6 +1008,14 @@ class Sint16(CIMInt):
     A value of CIM data type sint16. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          'x' may be a position or keyword argument.
+
+        base (:term:`integer`):
+          A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -1011,6 +1033,14 @@ class Uint32(CIMInt):
     A value of CIM data type uint32. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          x' may be a position or keyword argument.
+
+          base (:term:`integer`):
+            'x' may be a position or keyword argument.
     """
 
     __slots__ = []
@@ -1028,6 +1058,14 @@ class Sint32(CIMInt):
     A value of CIM data type sint32. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          'x' may be a position or keyword argument.
+
+        base (:term:`integer`):
+          A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -1045,6 +1083,14 @@ class Uint64(CIMInt):
     A value of CIM data type uint64. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          'x' may be a position or keyword argument.
+
+        base (:term:`integer`):
+          A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -1062,6 +1108,14 @@ class Sint64(CIMInt):
     A value of CIM data type sint64. Derived from :class:`~pywbem.CIMInt`.
 
     For details on CIM integer data types, see :class:`~pywbem.CIMInt`.
+
+    Parameters:
+        x (:term:`integer` or :term:`string`):
+          A number or a string that can be converted into an integer number.
+          'x' may be a position or keyword argument.
+
+        base (:term:`integer`):
+          A number representing the number format (radix). Default value: 10.
     """
 
     __slots__ = []
@@ -1100,7 +1154,15 @@ class CIMFloat(CIMType, float):
 
     __slots__ = []
 
-    # Note: __str__() is added later, for Python 3.
+    def __str__(self):
+        """
+        Return a string representation of the value. Python 3.8 removed
+        __str__() on float causing an infinite recursion for the CIMInt and
+        class whose __repr__() calls __str__() on itself. The
+        float.__repr__method returns exactly what is needed for a string
+        representation.
+        """
+        return float.__repr__(self)
 
     def __repr__(self):
         """Return a string representation suitable for debugging."""
@@ -1142,21 +1204,7 @@ class Real64(CIMFloat):
 
 
 # Python number types listed in :term:`number`.
-number_types = six.integer_types + (float,)  # pylint: disable=invalid-name
-
-
-# Python 3.8 removed __str__() on int and float and thereby caused an infinite
-# recursion for the CIMInt and CIMFloat classes whose __repr__() calls
-# __str__() on itself.
-# The following addresses that by implementing __str__() on these classes,
-# representing the values using int/float.__repr__(). In Python 3, these
-# methods return exactly what is needed for a string representation. Note that
-# in Python 2, repr(long) has a trailing 'L' which would not be suitable.
-if six.PY3:  # all Python 3.x, for simplicity.
-    CIMInt.__str__ = int.__repr__
-    CIMFloat.__str__ = float.__repr__
-    # MinutesFromUTC.__repr__() does not call str() on itself
-    # CIMDatetime has its own __str__()
+number_types = (int, float)  # pylint: disable=invalid-name
 
 
 def cimtype(obj):
@@ -1194,7 +1242,7 @@ def cimtype(obj):
     if isinstance(obj, bool):
         return 'boolean'
 
-    if isinstance(obj, (six.binary_type, six.text_type)):
+    if isinstance(obj, (bytes, str)):
         # accept both possible types
         return 'string'
 
@@ -1235,8 +1283,8 @@ def cimtype(obj):
 
 _TYPE_FROM_NAME = {
     'boolean': bool,
-    'string': six.text_type,  # return the preferred type
-    'char16': six.text_type,  # return the preferred type
+    'string': str,  # return the preferred type
+    'char16': str,  # return the preferred type
     'datetime': CIMDateTime,
     # 'reference' covered at run time
     'uint8': Uint8,
@@ -1338,23 +1386,23 @@ def atomic_to_cim_xml(obj):
     """
     if obj is None:  # pylint: disable=no-else-return
         return obj
-    elif isinstance(obj, six.text_type):
+    elif isinstance(obj, str):
         return obj
-    elif isinstance(obj, six.binary_type):
+    elif isinstance(obj, bytes):
         return _to_unicode(obj)
     elif isinstance(obj, bool):
-        return u'TRUE' if obj else u'FALSE'
-    elif isinstance(obj, (CIMInt, six.integer_types, CIMDateTime)):
-        return six.text_type(obj)
+        return 'TRUE' if obj else 'FALSE'
+    elif isinstance(obj, (CIMInt, int, CIMDateTime)):
+        return str(obj)
     elif isinstance(obj, datetime):
-        return six.text_type(CIMDateTime(obj))
+        return str(CIMDateTime(obj))
     elif isinstance(obj, Real32):
         # DSP0201 requirements for representing real32:
         # The significand must be represented with at least 11 digits.
         # The special values must have the case: INF, -INF, NaN.
-        s = u'{0:.11G}'.format(obj)
+        s = f'{obj:.11G}'
         if s == 'NAN':
-            s = u'NaN'
+            s = 'NaN'
         elif s in ('INF', '-INF'):
             pass
         elif '.' not in s:
@@ -1366,9 +1414,9 @@ def atomic_to_cim_xml(obj):
         # DSP0201 requirements for representing real64:
         # The significand must be represented with at least 17 digits.
         # The special values must have the case: INF, -INF, NaN.
-        s = u'{0:.17G}'.format(obj)
+        s = f'{obj:.17G}'
         if s == 'NAN':
-            s = u'NaN'
+            s = 'NaN'
         elif s in ('INF', '-INF'):
             pass
         elif '.' not in s:
