@@ -52,15 +52,6 @@ termed `pywbem loggers`:
 
 Pywbem uses the ``DEBUG`` logging level (see :ref:`py:levels`) for both loggers.
 
-Pywbem adds a null handler to the logger named `'pywbem'`, in order to prevent
-the "No handlers could be found for logger ..." warning.
-This follows best practices recommended in `Configuring logging for a library
-<https://docs.python.org/2/howto/logging.html#configuring-logging-for-a-library>`_
-and in several articles, for example in `this article
-<http://pieces.openpolitics.com/2012/04/python-logging-best-practices/>`_.
-Because this warning is no longer issued on Python 3.5 and higher, pywbem
-adds a null handler only on Python 2.7.
-
 Because pywbem logs only at the ``DEBUG`` logging level (see :ref:`py:levels`),
 these log events will not be printed by the Python root logger by default, and
 therefore it is not necessary that pywbem attaches a null handler to any of its
