@@ -1,4 +1,3 @@
-
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -21,17 +20,10 @@
 Operation recorder interface and implementations.
 """
 
-from __future__ import print_function, absolute_import
-import io
-from collections import namedtuple
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict  # pylint: disable=import-error
+from collections import namedtuple, OrderedDict
 from datetime import datetime, timedelta
 import logging
 
-import six
 import yaml
 import yamlloader
 
@@ -49,12 +41,6 @@ __all__ = ['BaseOperationRecorder', 'TestClientRecorder',
            'LogOperationRecorder',
            'OpArgs', 'OpResult', 'HttpRequest', 'HttpResponse']
 
-if six.PY2:
-    # pylint: disable=invalid-name, undefined-variable
-    _Longint = long  # noqa: F821
-else:
-    # pylint: disable=invalid-name
-    _Longint = int
 
 OpArgsTuple = namedtuple("OpArgsTuple", ["method", "args"])
 
@@ -209,7 +195,7 @@ class HttpResponse(HttpResponseTuple):
             s=self)
 
 
-class BaseOperationRecorder(object):
+class BaseOperationRecorder:
     # pylint: disable=too-many-instance-attributes
     """
     Abstract base class defining the interface to an operation recorder,
@@ -309,7 +295,7 @@ class BaseOperationRecorder(object):
             recorder_file.close()
         """
         # pylint: disable=consider-using-with
-        return io.open(filename, file_mode, encoding='utf-8')
+        return open(filename, file_mode, encoding='utf-8')
 
     def reset(self, pull_op=None):
         """Reset all the attributes in the class. This also allows setting
@@ -491,7 +477,7 @@ class LogOperationRecorder(BaseOperationRecorder):
             :data:`~pywbem._logging.LOG_DETAIL_LEVELS`, or an integer that
             specifies the maximum size of each log record.
         """
-        super(LogOperationRecorder, self).__init__()
+        super().__init__()
 
         self._conn_id = conn_id
 
@@ -594,10 +580,10 @@ class LogOperationRecorder(BaseOperationRecorder):
         if self.enabled and self.api_detail_level is not None and \
                 self.apilogger.isEnabledFor(logging.DEBUG):
 
-            # Order kwargs.  Note that this is done automatically starting
-            # with python 3.6
-            kwstr = ', '.join([('{0}={1!r}'.format(key, kwargs[key]))
-                               for key in sorted(six.iterkeys(kwargs))])
+            # Order kwargs.
+            # Sort required to pass tests. Ordering issue without this sort.
+            kwstr = ', '.join([(f'{key}={kwargs[key]!r}')
+                               for key in sorted(kwargs.keys())])
 
             if self.api_maxlen and (len(kwstr) > self.api_maxlen):
                 kwstr = kwstr[:self.api_maxlen] + '...'
@@ -723,11 +709,11 @@ class LogOperationRecorder(BaseOperationRecorder):
                 headers['Authorization'] = _format(
                     "{0} {1}", authtype, 'X' * len(cred))
 
-            header_str = ' '.join('{0}:{1!r}'.format(k, v)
+            header_str = ' '.join(f'{k}:{v!r}'
                                   for k, v in headers.items())
             if self.http_detail_level == 'summary':
                 upayload = ""
-            elif isinstance(payload, six.binary_type):
+            elif isinstance(payload, bytes):
                 upayload = payload.decode('utf-8')
             else:
                 upayload = payload
@@ -760,7 +746,7 @@ class LogOperationRecorder(BaseOperationRecorder):
                 self.httplogger.isEnabledFor(logging.DEBUG):
             if self._http_response_headers:
                 header_str = \
-                    ' '.join('{0}:{1!r}'.format(k, v)
+                    ' '.join(f'{k}:{v!r}'
                              for k, v in self._http_response_headers.items())
             else:
                 header_str = ''
@@ -836,7 +822,7 @@ class TestClientRecorder(BaseOperationRecorder):
             :meth:`~pywbem.BaseOperationRecorder.open_file`
             can be used to open the file.
 
-            Alternatively, the Python 2/3 compatible :func:`py:io.open` can be
+            Alternatively, the Python 2/3 compatible :func:`py:open` can be
             used.
 
         Examples::
@@ -845,9 +831,9 @@ class TestClientRecorder(BaseOperationRecorder):
               BaseOperationRecorder.open_file('recorder.log'))
 
           recorder = TestClientRecorder(
-              io.open('recorder.log', mode='w', encoding='utf-8')
+              open('recorder.log', mode='w', encoding='utf-8')
         """
-        super(TestClientRecorder, self).__init__()
+        super().__init__()
         self._fp = fp
 
     def copy(self):
@@ -996,26 +982,17 @@ class TestClientRecorder(BaseOperationRecorder):
             return ret_dict
         if obj is None:
             return obj
-        if isinstance(obj, six.binary_type):
+        if isinstance(obj, bytes):
             return obj.decode("utf-8")
-        if isinstance(obj, six.text_type):
+        if isinstance(obj, str):
             return obj
         if isinstance(obj, bool):
             # The check for bool must be before any integer checks, because
             # bool is a subclass of int in Python.
             return obj
         if isinstance(obj, CIMInt):
-            # CIMInt is _Longint and therefore may exceed the value range of
-            # int in Python 2. Therefore, we convert it to _Longint.
-            return _Longint(obj)
-        if isinstance(obj, six.integer_types):
-            # This case must be after CIMInt, because CIMInt is _Longint and
-            # would match a long value in Python 2.
-            # We don't convert six.integer_types to _Longint, because the value
-            # fits into the provided type, and there is no need to convert it.
-            # Note that in Python 2 (where that would make a difference), int
-            # and long do not inherit from each other, so it is likely best if
-            # we just don't convert.
+            return int(obj)
+        if isinstance(obj, int):
             return obj
         if isinstance(obj, CIMFloat):
             return float(obj)
