@@ -76,10 +76,8 @@ representation of CIM in XML by having the following properties:
 
 # This module is meant to be safe for 'import *'.
 
-from __future__ import absolute_import
 import re
 import warnings
-import six
 
 from ._utils import _stacklevel_above_module, _format
 from ._nocasedict import NocaseDict
@@ -142,12 +140,12 @@ def pcdata(tup_tree):
     # The callers have already ensured that that is not the case.
     # The following assertion has been verified and disabled again for
     # performance reasons:
-    # assert all([isinstance(n, six.string_types) for n in k])
+    # assert all([isinstance(n, str) for n in k])
 
-    return u''.join(k)
+    return ''.join(k)
 
 
-class TupleParser(object):
+class TupleParser:
     """
     Parser for a CIM XML tupletree.
     """
@@ -238,7 +236,7 @@ class TupleParser(object):
 
         if not allow_pcdata:
             for child in tup_tree[2]:
-                if isinstance(child, six.string_types):
+                if isinstance(child, str):
                     if child.lstrip(' \t\n') != '':
                         raise CIMXMLParseError(
                             _format("Element {0!A} has unexpected non-blank "
@@ -804,7 +802,7 @@ class TupleParser(object):
         # faster.
         ns_list = self.list_of_various(tup_tree, ('NAMESPACE',))
 
-        return u'/'.join(ns_list)
+        return '/'.join(ns_list)
 
     def parse_host(self, tup_tree):
         """
@@ -1120,7 +1118,7 @@ class TupleParser(object):
         If TYPE is not specified but VALUETYPE is specified, the CIM type is
         defaulted for a VALUETYPE of 'string' and 'boolean'. For a VALUETYPE of
         'numeric', the CIM type remains undetermined and the numeric values are
-        returned as Python int/long or float objects.
+        returned as Python int or float objects.
 
           ::
 
@@ -2254,7 +2252,7 @@ class TupleParser(object):
                                      'INSTANCE', 'VALUE.NAMEDINSTANCE'))
 
         _name = attrs(tup_tree)['NAME']
-        if isinstance(child, six.string_types) and \
+        if isinstance(child, str) and \
                 _name.lower() in ('deepinheritance', 'localonly',
                                   'includequalifiers', 'includeclassorigin'):
             if child.lower() in ('true', 'false'):
@@ -2395,7 +2393,7 @@ class TupleParser(object):
         """
         Unpack a single (non-array) CIM typed string value of any CIM type
         except 'reference' and return it as a CIM data type object, or Python
-        int/long/float, or None.
+        int/float, or None.
 
         data (unicode string): CIM-XML string value, or None (in which case
           None is returned).
@@ -2463,7 +2461,7 @@ class TupleParser(object):
         data (unicode string): CIM-XML string value. Must not be None.
 
         cimtype (string): CIM data type name (e.g. 'uint8'), or None (in which
-          case the value is returned as a Python int/long or float).
+          case the value is returned as a Python int or float).
         """
 
         assert data is not None
@@ -2476,7 +2474,6 @@ class TupleParser(object):
         # Some notes:
         # * For integer numbers, only decimal and hexadecimal strings are
         #   allowed - no binary or octal.
-        # * In Python 2, int() automatically returns a long, if needed.
         # * For real values, DSP0201 defines a subset of the syntax supported
         #   by Python float(), including the special states Inf, -Inf, NaN. The
         #   only known difference is that DSP0201 requires a digit after the
@@ -2498,7 +2495,7 @@ class TupleParser(object):
 
         # Convert the Python number into a CIM data type
         if cimtype is None:
-            return value  # int/long or float (used for keybindings)
+            return value  # int or float (used for keybindings)
 
         # The caller ensured a numeric type for cimtype
         CIMType = type_from_name(cimtype)
