@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -105,12 +104,7 @@ Limitations:
 """
 
 import re
-try:
-    from collections.abc import Sequence
-except ImportError:
-    # pylint: disable=deprecated-class
-    from collections import Sequence
-import six
+from collections.abc import Sequence
 
 from ._vendor.nocasedict import NocaseDict
 from ._cim_obj import CIMProperty, CIMMethod, CIMParameter
@@ -162,9 +156,8 @@ def siunit_obj(cim_obj, use_ascii=False):
     # pylint: enable=line-too-long
 
     if not isinstance(cim_obj, (CIMProperty, CIMMethod, CIMParameter)):
-        raise TypeError("Invalid type for cim_obj: {}, "
-                        "must be CIMProperty, CIMMethod, or CIMParameter".
-                        format(type(cim_obj)))
+        raise TypeError(f"Invalid type for cim_obj: {type(cim_obj)}, "
+                        "must be CIMProperty, CIMMethod, or CIMParameter")
 
     punit_q = cim_obj.qualifiers.get('PUnit', None)
     punit = punit_q.value if punit_q else None
@@ -241,30 +234,30 @@ def siunit(punit=None, units=None, use_ascii=False):
 
 
 # Unicode characters used in the output, by default
-UC_DEGREE = u'\u00B0'  # U+00B0: DEGREE SIGN
+UC_DEGREE = '\u00B0'  # U+00B0: DEGREE SIGN
 # U+2103 (DEGREE CELSIUS) and U+2109 (DEGREE FAHRENHEIT) are intentionally
 # not used, for better font/terminal compatibility.
-UC_DEGREE_CELSIUS = u'{}C'.format(UC_DEGREE)  # Avoid U+2103: DEGREE CELSIUS
-UC_DEGREE_FAHRENHEIT = u'{}F'.format(UC_DEGREE)  # Avoid U+2109: DEGREE FAHR.
-UC_PERMILLE = u'\u2030'  # U+2030: PER MILLE SIGN
-UC_MICRO = u'\u00B5'  # U+00B5: MICRO SIGN
-UC_OHM = u'\u2126'  # U+2126: OHM SIGN
-UC_SUP_2 = u'\u00B2'  # U+00B2: SUPERSCRIPT TWO
-UC_SUP_3 = u'\u00B3'  # U+00B3: SUPERSCRIPT THREE
+UC_DEGREE_CELSIUS = f'{UC_DEGREE}C'  # Avoid U+2103: DEGREE CELSIUS
+UC_DEGREE_FAHRENHEIT = f'{UC_DEGREE}F'  # Avoid U+2109: DEGREE FAHR.
+UC_PERMILLE = '\u2030'  # U+2030: PER MILLE SIGN
+UC_MICRO = '\u00B5'  # U+00B5: MICRO SIGN
+UC_OHM = '\u2126'  # U+2126: OHM SIGN
+UC_SUP_2 = '\u00B2'  # U+00B2: SUPERSCRIPT TWO
+UC_SUP_3 = '\u00B3'  # U+00B3: SUPERSCRIPT THREE
 # U+2074 (SUPERSCRIPT FOUR) and adjacent characters up to U+2079
 # (SUPERSCRIPT NINE) are intentionally not used, for better font/terminal
 # compatibility.
 
 # 7-bit ASCII replacements for the Unicode characters above
 UC2ASCII = {
-    UC_DEGREE: u'deg',
-    UC_DEGREE_CELSIUS: u'degC',
-    UC_DEGREE_FAHRENHEIT: u'degF',
-    UC_PERMILLE: u'1/1000',
-    UC_MICRO: u'u',
-    UC_OHM: u'Ohm',
-    UC_SUP_2: u'^2',
-    UC_SUP_3: u'^3',
+    UC_DEGREE: 'deg',
+    UC_DEGREE_CELSIUS: 'degC',
+    UC_DEGREE_FAHRENHEIT: 'degF',
+    UC_PERMILLE: '1/1000',
+    UC_MICRO: 'u',
+    UC_OHM: 'Ohm',
+    UC_SUP_2: '^2',
+    UC_SUP_3: '^3',
 }
 
 # Components in the PUnit regexp pattern, named consistent with ABNF in
@@ -272,18 +265,16 @@ UC2ASCII = {
 SIMPLE_NAME = r'[A-Za-z_][A-Za-z_\-0-9 ]*?'
 WS = r'[ \t\n]?'  # optionality already included
 SP = r'[ ]?'  # optionality already included
-POSITIVE_WHOLE_NUMBER = r'[1-9][0-9]*'
-POSITIVE_NUMBER = r'(?:{pwn}|(?:{pwn}|0)\.[0-9]*)'. \
-    format(pwn=POSITIVE_WHOLE_NUMBER)
-NUMBER = r'[\+\-]?{pn}'.format(pn=POSITIVE_NUMBER)
-EXPONENT = r'[\+\-]?{pwn}'.format(pwn=POSITIVE_WHOLE_NUMBER)
-DECIBEL_BASE_UNIT = r'decibel{sp}\({sn}\)'.format(sp=SP, sn=SIMPLE_NAME)
+POS_WHOLE_NUMBER = r'[1-9][0-9]*'
+POS_NUMBER = fr'(?:{POS_WHOLE_NUMBER}|(?:{POS_WHOLE_NUMBER}|0)\.[0-9]*)'
+NUMBER = fr'[\+\-]?{POS_NUMBER}'
+EXPONENT = fr'[\+\-]?{POS_WHOLE_NUMBER}'
+DECIBEL_BASE_UNIT = fr'decibel{SP}\({SIMPLE_NAME}\)'
 
-BASE_UNIT = r'(?:{sn}|{dbu})'.format(sn=SIMPLE_NAME, dbu=DECIBEL_BASE_UNIT)
+BASE_UNIT = fr'(?:{SIMPLE_NAME}|{DECIBEL_BASE_UNIT})'
 
 # The top-level components in the (extended) PUnit formula
-TOP_COMP = r'(?:{bu}|{n}|{pwn}{ws}\^{ws}{e})'. \
-    format(bu=BASE_UNIT, ws=WS, n=NUMBER, pwn=POSITIVE_WHOLE_NUMBER, e=EXPONENT)
+TOP_COMP = fr'(?:{BASE_UNIT}|{NUMBER}|{POS_WHOLE_NUMBER}{WS}\^{WS}{EXPONENT})'
 
 # The pattern for the (extended) PUnit formula. This is an extended version
 # of the programmatic-unit term in DSP0004, whereby the top-level components
@@ -296,15 +287,13 @@ TOP_COMP = r'(?:{bu}|{n}|{pwn}{ws}\^{ws}{e})'. \
 # Note that the pattern allows for numeric modifiers to appear more than
 # once, but DSP0004 allows only one whole number modifier (mod1) and one
 # exponential number modifier (mod2). This is verified in the function.
-PUNIT = r'^({bu})((?:{ws}(?:\*|/){ws}{tc})*)$'. \
-    format(bu=BASE_UNIT, tc=TOP_COMP, ws=WS)
+PUNIT = fr'^({BASE_UNIT})((?:{WS}(?:\*|/){WS}{TOP_COMP})*)$'
 PUNIT_PATTERN = re.compile(PUNIT)
 
 # The modifier 1 and 2 patterns
-MOD1_PATTERN = re.compile(r'^{ws}({n}){ws}$'.
-                          format(ws=WS, n=NUMBER))
-MOD2_PATTERN = re.compile(r'^{ws}({pwn}){ws}\^{ws}({e}){ws}$'.
-                          format(ws=WS, pwn=POSITIVE_WHOLE_NUMBER, e=EXPONENT))
+MOD1_PATTERN = re.compile(fr'^{WS}({NUMBER}){WS}$')
+MOD2_PATTERN = re.compile(
+    fr'^{WS}({POS_WHOLE_NUMBER}){WS}\^{WS}({EXPONENT}){WS}$')
 
 # The abbreviated SI units for each PUnit base unit defined in DSP0004
 PUNIT_SIUNIT = NocaseDict([
@@ -430,7 +419,7 @@ PUNIT_MOD2_SIPREFIX = {
 # Dictionary to map unit power integer numbers to a suitable superscript
 # Unicode character.
 PUNIT_POWER = {
-    1: u'',
+    1: '',
     2: UC_SUP_2,
     3: UC_SUP_3,
 }
@@ -624,9 +613,9 @@ def _siunit_from_punit(punit):
       ValueError: Unknown base unit in PUnit qualifier value
     """
 
-    if not isinstance(punit, six.string_types):
-        raise TypeError("Invalid type for punit: {}, must be string".
-                        format(type(punit)))
+    if not isinstance(punit, str):
+        raise TypeError(
+            f"Invalid type for punit: {type(punit)}, must be string")
 
     if punit == '':
         return ''
@@ -635,7 +624,7 @@ def _siunit_from_punit(punit):
     m = PUNIT_PATTERN.match(punit)
     if m is None:
         raise ValueError(
-            "Invalid format in PUnit qualifier: {!r}".format(punit))
+            f"Invalid format in PUnit qualifier: {punit!r}")
 
     base_unit = m.group(1)
     comp_str = m.group(2)
@@ -669,13 +658,13 @@ def _siunit_from_punit(punit):
             try:
                 mod2_prefix = PUNIT_MOD2_SIPREFIX[(mod2_base, mod2_exp)]
             except KeyError:
-                mod2_prefix = "{}^{} ".format(mod2_base, mod2_exp)
+                mod2_prefix = f"{mod2_base}^{mod2_exp} "
         else:
             assert mod2_op == '/'
             try:
                 mod2_prefix = PUNIT_MOD2_SIPREFIX[(mod2_base, -mod2_exp)]
             except KeyError:
-                mod2_prefix = "{}^{} ".format(mod2_base, -mod2_exp)
+                mod2_prefix = f"{mod2_base}^{-mod2_exp} "
     else:
         mod2_prefix = ""
 
@@ -683,24 +672,24 @@ def _siunit_from_punit(punit):
     if mod1:
         mod1_op, mod1_num = mod1
         if mod1_op == '*':
-            mod1_str = "{}".format(mod1_num)
+            mod1_str = f"{mod1_num}"
             if mod2_prefix:
-                mod1_prefix = "{} ".format(mod1_str)
+                mod1_prefix = f"{mod1_str} "
             else:
                 try:
                     mod1_prefix = PUNIT_MOD1_SIPREFIX[mod1_str]
                 except KeyError:
-                    mod1_prefix = "{} ".format(mod1_str)
+                    mod1_prefix = f"{mod1_str} "
         else:
             assert mod1_op == '/'
-            mod1_str = "1/{}".format(mod1_num)
+            mod1_str = f"1/{mod1_num}"
             if mod2_prefix:
-                mod1_prefix = "{} ".format(mod1_str)
+                mod1_prefix = f"{mod1_str} "
             else:
                 try:
                     mod1_prefix = PUNIT_MOD1_SIPREFIX[mod1_str]
                 except KeyError:
-                    mod1_prefix = "{} ".format(mod1_str)
+                    mod1_prefix = f"{mod1_str} "
     else:
         mod1_prefix = ""
 
@@ -720,7 +709,7 @@ def _mod12(op, comp, mod1, mod2, punit):
         if mod1:
             raise ValueError(
                 "Numeric modifier 1 appears more than once in PUnit "
-                "qualifier: {!r}".format(punit))
+                f"qualifier: {punit!r}")
         mod1_num = int(m.group(1))
         mod1 = (op, mod1_num)
         return mod1, mod2, None
@@ -730,7 +719,7 @@ def _mod12(op, comp, mod1, mod2, punit):
         if mod2:
             raise ValueError(
                 "Numeric modifier 2 appears more than once in PUnit "
-                "qualifier: {!r}".format(punit))
+                f"qualifier: {punit!r}")
         mod2_base = int(m.group(1))
         mod2_exp = int(m.group(2))
         mod2 = (op, mod2_base, mod2_exp)
@@ -780,7 +769,7 @@ def _get_punit_siunit(punit):
         _siunit = PUNIT_SIUNIT[punit]
     except KeyError:
         new_exc = ValueError(
-            "Unknown base unit in PUnit qualifier value: {}".format(punit))
+            f"Unknown base unit in PUnit qualifier value: {punit}")
         new_exc.__cause__ = None
         raise new_exc
     return _siunit
@@ -790,11 +779,11 @@ def _get_punit_power(power):
     """
     Return the power integer as a string.
     """
-    assert isinstance(power, six.integer_types)
+    assert isinstance(power, int)
     try:
         _power = PUNIT_POWER[power]
     except KeyError:
-        _power = "^{}".format(power)
+        _power = f"^{power}"
     return _power
 
 
@@ -820,14 +809,14 @@ def _siunit_from_units(units):
       ValueError: Unknown unit in Units qualifier
     """
 
-    if not isinstance(units, six.string_types):
-        raise TypeError("Invalid type for units: {}, must be string".
-                        format(type(units)))
+    if not isinstance(units, str):
+        raise TypeError(
+            f"Invalid type for units: {type(units)}, must be string")
 
     try:
         return UNITS_SIUNIT[units]
     except KeyError:
         new_exc = ValueError(
-            "Unknown unit in Units qualifier: {!r}".format(units))
+            f"Unknown unit in Units qualifier: {units!r}")
         new_exc.__cause__ = None
         raise new_exc
