@@ -25,11 +25,7 @@ This class supports value ranges (e.g. ``"4..6"``) and the unclaimed marker
 """
 
 import re
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
-import six
+from collections import OrderedDict
 
 from ._cim_types import CIMInt, type_from_name
 from ._cim_obj import CIMProperty, CIMMethod, CIMParameter
@@ -39,7 +35,7 @@ from ._exceptions import ModelError
 __all__ = ['ValueMapping']
 
 
-class ValueMapping(object):
+class ValueMapping:
     """
     *New in pywbem 0.9 as experimental and finalized in 0.10.*
 
@@ -106,7 +102,7 @@ class ValueMapping(object):
           print("Binary value: Values string")
           for bin_value in range(0, 12):
               values_str = myprop_vm.tovalues(bin_value)
-              print("{0:12}: {1!r}".format(bin_value, values_str))
+              print(f"{bin_value:12}: {values_str!r}")
 
       Resulting output:
 
@@ -149,7 +145,7 @@ class ValueMapping(object):
           print("Values string: Binary value")
           for values_str in values_strs:
               bin_value = myprop_vm.tobinary(values_str)
-              print("{0:12}: {1!r}".format(values_str, bin_value))
+              print(f"{values_str:12}: {bin_value!r}")
 
       Resulting output:
 
@@ -176,7 +172,7 @@ class ValueMapping(object):
 
           print("Values string: Binary value")
           for bin_value, values_str in myprop_vm.items():
-              print("{0:12}: {1!r}".format(values_str, bin_value))
+              print(f"{values_str:12}: {bin_value!r}")
 
       Resulting output:
 
@@ -636,7 +632,7 @@ class ValueMapping(object):
         valuemap_qual = element_obj.qualifiers.get('ValueMap', None)
         if valuemap_qual is None:
             # DSP0004 defines a default of consecutive index numbers
-            valuemap_list = ["{}".format(v) for v in range(0, len(values_list))]
+            valuemap_list = [f"{v}" for v in range(0, len(values_list))]
         else:
             valuemap_list = valuemap_qual.value
 
@@ -862,7 +858,7 @@ class ValueMapping(object):
           TypeError: Element value is not an integer type.
         """
 
-        if not isinstance(element_value, (six.integer_types, CIMInt)):
+        if not isinstance(element_value, (int, CIMInt)):
             raise TypeError(
                 _format("The value for value-mapped {0} is not "
                         "integer-typed, but has Python type: {1}",
@@ -931,7 +927,7 @@ class ValueMapping(object):
           TypeError: `Values` string is not a string type.
         """
 
-        if not isinstance(values_str, six.string_types):
+        if not isinstance(values_str, str):
             raise TypeError(
                 _format("The values string for value-mapped {0} is not "
                         "string-typed, but has Python type: {1}",
