@@ -34,7 +34,6 @@ following functionality:
   defined in _wbemconnection_mock
 """
 
-from __future__ import absolute_import, print_function
 
 from pywbem._vendor.nocaselist import NocaseList
 from pywbem import CIMError, \
@@ -51,7 +50,7 @@ from pywbem._utils import _format
 __all__ = ['BaseProvider']
 
 
-class BaseProvider(object):
+class BaseProvider:
     """
     BaseProvider is the top level class in the provider hierarchy and includes
     methods required by both builtin providers and user-defined providers.
@@ -201,8 +200,7 @@ class BaseProvider(object):
                             "CIM repository. {1!A} cannot be added. ",
                             self.find_interop_namespace(), namespace))
         if verbose:
-            print("Creating namespace {} (in mock support)".
-                  format(namespace))
+            print(f"Creating namespace {namespace} (in mock support)")
         try:
             self.cimrepository.add_namespace(namespace)
         except ValueError:
@@ -260,8 +258,7 @@ class BaseProvider(object):
                         "the CIM repository.", namespace))
 
         if verbose:
-            print("Deleting namespace {} (in mock support)".
-                  format(namespace))
+            print(f"Deleting namespace {namespace} (in mock support)")
         try:
             self.cimrepository.remove_namespace(namespace)
         # KeyError cannot happen because existence was already verified
