@@ -42,7 +42,6 @@ not know.
 They do not exist for DeleteInstances. Ex. You cannot delete a filter that
 is included in a subscription.
 """
-import six
 
 from pywbem import CIMError, CIM_ERR_NOT_SUPPORTED, \
     CIM_ERR_INVALID_PARAMETER, CIM_ERR_FAILED, Uint16, CIMDateTime, \
@@ -74,7 +73,7 @@ def set_property(instance, name, value, conditional=True):
         instance[name] = value
 
 
-class CommonMethodsMixin(object):
+class CommonMethodsMixin:
     """
     Common Methods and functionality for the 3 providers defined to support
     indication subscriptions
@@ -301,7 +300,7 @@ class CommonMethodsMixin(object):
         # Validate provider classes installed.  Will generate exception
         # if class does not exist.
         interop_namespace = conn.find_interop_namespace()
-        if isinstance(self.provider_classnames, six.string_types):
+        if isinstance(self.provider_classnames, str):
             clns = [self.provider_classnames]
         else:
             clns = self.provider_classnames
@@ -347,7 +346,7 @@ class CIMIndicationFilterProvider(CommonMethodsMixin, InstanceWriteProvider):
           cimrepository (:class:`~pywbem_mock.BaseRepository` or subclass):
             Defines the CIM repository to be used by the provider.
         """
-        super(CIMIndicationFilterProvider, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
         if not self.find_interop_namespace():
             raise CIMError(
@@ -423,7 +422,7 @@ class CIMIndicationFilterProvider(CommonMethodsMixin, InstanceWriteProvider):
 
         # Create the CIM instance for the new namespace in the CIM repository,
         # by delegating to the default provider method.
-        return super(CIMIndicationFilterProvider, self).CreateInstance(
+        return super().CreateInstance(
             namespace, new_instance)
 
     def ModifyInstance(self, modified_instance, IncludeQualifiers=None):
@@ -441,7 +440,7 @@ class CIMIndicationFilterProvider(CommonMethodsMixin, InstanceWriteProvider):
             modifiable_properties=modifiable_properties,
             IncludeQualifiers=IncludeQualifiers)
 
-        return super(CIMIndicationFilterProvider, self).ModifyInstance(
+        return super().ModifyInstance(
             modified_instance, IncludeQualifiers=IncludeQualifiers)
 
     def DeleteInstance(self, InstanceName):  # pylint: disable=invalid-name
@@ -521,7 +520,7 @@ class CIMListenerDestinationProvider(CommonMethodsMixin, InstanceWriteProvider):
           cimrepository (:class:`~pywbem_mock.BaseRepository` or subclass):
             Defines the CIM repository to be used by the provider.
         """
-        super(CIMListenerDestinationProvider, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
         if not self.find_interop_namespace():
             raise CIMError(
@@ -609,7 +608,7 @@ class CIMListenerDestinationProvider(CommonMethodsMixin, InstanceWriteProvider):
 
         # Create the CIM instance for the new namespace in the CIM repository,
         # by delegating to the default provider method.
-        return super(CIMListenerDestinationProvider, self).CreateInstance(
+        return super().CreateInstance(
             namespace, new_instance)
 
     def ModifyInstance(self, modified_instance, IncludeQualifiers=None):
@@ -626,7 +625,7 @@ class CIMListenerDestinationProvider(CommonMethodsMixin, InstanceWriteProvider):
             modifiable_properties=modifiable_properties,
             IncludeQualifiers=IncludeQualifiers)
 
-        return super(CIMListenerDestinationProvider, self).ModifyInstance(
+        return super().ModifyInstance(
             modified_instance, IncludeQualifiers=IncludeQualifiers)
 
     def DeleteInstance(self, InstanceName):  # pylint: disable=invalid-name
@@ -662,7 +661,7 @@ class CIMListenerDestinationProvider(CommonMethodsMixin, InstanceWriteProvider):
 
         self.validate_no_subscription(InstanceName)
 
-        return super(CIMListenerDestinationProvider, self).DeleteInstance(
+        return super().DeleteInstance(
             InstanceName)
 
 
@@ -704,7 +703,7 @@ class CIMIndicationSubscriptionProvider(CommonMethodsMixin,
           cimrepository (:class:`~pywbem_mock.BaseRepository` or subclass):
             Defines the CIM repository to be used by the provider.
         """
-        super(CIMIndicationSubscriptionProvider, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
         if not self.find_interop_namespace():
             raise CIMError(
@@ -792,7 +791,7 @@ class CIMIndicationSubscriptionProvider(CommonMethodsMixin,
 
         # Create the CIM instance for the new namespace in the CIM repository,
         # by delegating to the default provider method.
-        return super(CIMIndicationSubscriptionProvider, self).CreateInstance(
+        return super().CreateInstance(
             namespace, new_instance)
 
     def ModifyInstance(self, modified_instance, IncludeQualifiers=None):
@@ -824,7 +823,7 @@ class CIMIndicationSubscriptionProvider(CommonMethodsMixin,
 
         modified_instance['TimeOfLastStateChange'] = CIMDateTime.now()
 
-        return super(CIMIndicationSubscriptionProvider, self).ModifyInstance(
+        return super().ModifyInstance(
             modified_instance, IncludeQualifiers=IncludeQualifiers)
 
     def DeleteInstance(self, InstanceName):  # pylint: disable=invalid-name
@@ -858,5 +857,5 @@ class CIMIndicationSubscriptionProvider(CommonMethodsMixin,
         assert InstanceName.classname.lower() == \
             CIMIndicationSubscriptionProvider.provider_classnames.lower()
 
-        return super(CIMIndicationSubscriptionProvider, self).DeleteInstance(
+        return super().DeleteInstance(
             InstanceName)
